collapsedIconTapHint property
The semantics hint to describe the tap action on a collapsed ExpandIcon.
Implementation
@override
String get collapsedIconTapHint => _isKmr ? 'Fireh bike' : 'فراوانکردن';
The semantics hint to describe the tap action on a collapsed ExpandIcon.
@override
String get collapsedIconTapHint => _isKmr ? 'Fireh bike' : 'فراوانکردن';