dateOutOfRangeLabel property
Error message displayed to the user when they have entered a date that is outside the valid range for the date picker. showDateRangePicker.
Implementation
@override
String get dateOutOfRangeLabel =>
_isKmr ? 'Derveyî sînorê' : 'دەرەوەی مەودایە';