expandedIconTapHint property
The semantics hint to describe the tap action on an expanded ExpandIcon.
Implementation
@override
String get expandedIconTapHint => _isKmr ? 'Biçûk bike' : 'نوشتانەوە';
The semantics hint to describe the tap action on an expanded ExpandIcon.
@override
String get expandedIconTapHint => _isKmr ? 'Biçûk bike' : 'نوشتانەوە';