hideAccountsLabel property
The semantics label used for the button on UserAccountsDrawerHeader that hides the list of accounts.
Implementation
@override
String get hideAccountsLabel =>
_isKmr ? 'Ajimêran veşêre' : 'شاردنەوەی ئەژمێرەکان';
The semantics label used for the button on UserAccountsDrawerHeader that hides the list of accounts.
@override
String get hideAccountsLabel =>
_isKmr ? 'Ajimêran veşêre' : 'شاردنەوەی ئەژمێرەکان';