invalidDateFormatLabel property
Error message displayed to the user when they have entered a text string in an InputDatePickerFormField that is not in a valid date format.
Implementation
@override
String get invalidDateFormatLabel =>
_isKmr ? 'Format şaş e.' : 'فۆرماتی نادروست.';