showAccountsLabel property
The semantics label used for the button on UserAccountsDrawerHeader that shows the list of accounts.
Implementation
@override
String get showAccountsLabel =>
_isKmr ? 'Ajimêran nîşan bide' : 'پیشاندانی ئەژمێرەکان';
The semantics label used for the button on UserAccountsDrawerHeader that shows the list of accounts.
@override
String get showAccountsLabel =>
_isKmr ? 'Ajimêran nîşan bide' : 'پیشاندانی ئەژمێرەکان';